package main

import (
	"bytes"
	"fmt"
	"time"

	"github.com/olekukonko/tablewriter"
)

type Item struct {
	ID            string    `yaml:"ID"`
	Name          string    `yaml:"Name"`
	Type          string    `yaml:"Type"`
	Group         string    `yaml:"Group"`
	Description   string    `yaml:"Description"`
	DeliveryUntil time.Time `yaml:"Delivery until"`
	ProvidedOn    time.Time `yaml:"Provided on"`
	ProvidedBy    string    `yaml:"Provided by"`
}

func buildItemOverviewTable(config *Configuration, pageMap map[string]requirement, extended bool) (error, string, bool) {

	buf := new(bytes.Buffer)
	has := false

	table := tablewriter.NewWriter(buf)

	var header []string

	if extended {
		header = []string{
			printer.Sprintf("ID"),
			printer.Sprintf("Group"),
			printer.Sprintf("Name"),
			printer.Sprintf("Type"),
			printer.Sprintf("Description"),
			printer.Sprintf("Delivery until"),
			printer.Sprintf("Checked"),
			printer.Sprintf("Provided on"),
			printer.Sprintf("Provided by"),
			printer.Sprintf("File"),
		}
	} else {
		header = []string{
			printer.Sprintf("ID"),
			printer.Sprintf("Name"),
			printer.Sprintf("Delivery until"),
			printer.Sprintf("Checked"),
		}

	}

	table.SetHeader(header)

	table.SetBorders(tablewriter.Border{Left: true, Top: false, Right: true, Bottom: false})
	table.SetCenterSeparator("|")

	var tableData [][]string

	for _, pageData := range pageMap {
		for _, info := range pageData.Items {

			var deliveryUntilFormatted, providedOnDate, checked string

			if info.DeliveryUntil.IsZero() {
				deliveryUntilFormatted = "—"
			} else {
				deliveryUntilFormatted = info.DeliveryUntil.Format(config.Locale.DateFormat)
			}

			if info.ProvidedOn.IsZero() {
				providedOnDate = "—"
			} else {
				providedOnDate = info.ProvidedOn.Format(config.Locale.DateFormat)
			}

			if info.DeliveryUntil.IsZero() {
				deliveryUntilFormatted = "—"
			} else {
				deliveryUntilFormatted = info.DeliveryUntil.Format(config.Locale.DateFormat)
			}

			if info.ProvidedOn.IsZero() {
				checked = "—"
			} else {
				checked = "✓"
			}

			id := "—"
			if info.ID != "" {
				id = info.ID
			}

			var col []string

			if extended {
				col = []string{id, info.Group, info.Name, info.Type, info.Description, deliveryUntilFormatted, checked, providedOnDate, info.ProvidedBy, pageData.File}
			} else {
				col = []string{id, info.Name, deliveryUntilFormatted, deliveryUntilFormatted, checked}
			}

			tableData = append(tableData, col)
			has = true

		}

	}

	table.AppendBulk(tableData) // Add Bulk Data
	table.SetHeaderAlignment(tablewriter.ALIGN_LEFT)
	table.Render()

	return nil, buf.String(), has
}

func printItemTable(config *Configuration) error {
	err, pageMap := collectStructureFromFiles(config.Path)
	if err != nil {
		return err
	}

	err, table, _ := buildItemOverviewTable(config, pageMap, true)
	fmt.Println(table)

	return nil
}
