package main

import (
	"fmt"
	"strings"
)

type Privacy struct {
	ID                  string `yaml:"ID"`
	Purposes            string `yaml:"Purposes"`
	Description         string `yaml:"Description"`
	Contact             string `yaml:"Contact"`
	AffectedGroups      string `yaml:"Affected Groups"` // Employees, Suppliers, Customers, Job applicants, Consultants, Visitors, Prospects, Contractors, Trainees
	Category            string `yaml:"Category"`
	DataRetentionPeriod string `yaml:"Data Retention Period"`
	LegalBasis          string `yaml:"Legal Basis"`
	Consent             string `yaml:"Consent"`
	Transfers           string `yaml:"Transfers"`
	TOM                 string `yaml:"TOM"`
}

func buildPrivacy(config *Configuration, pageMap map[string]requirement) (error, string, bool) {

	hasPrivacy := false
	text := ""

	for _, pageData := range pageMap {
		for _, data := range pageData.Privacy {

			text += strings.Trim(data.Purposes+" ("+data.ID+")", " ") + "\n\n"

			d := strings.Trim(data.Description, " \n")
			if d != "" {
				text += d + "\n\n"
			}

			d = strings.Trim(data.Contact, " \n")
			if d != "" {
				text += d + "\n\n"
			}

			d = strings.Trim(data.AffectedGroups, " \n")
			if d != "" {
				text += d + "\n\n"
			}

			d = strings.Trim(data.Category, " \n")
			if d != "" {
				text += d + "\n\n"
			}

			d = strings.Trim(data.DataRetentionPeriod, " \n")
			if d != "" {
				text += d + "\n\n"
			}

			d = strings.Trim(data.LegalBasis, " \n")
			if d != "" {
				text += d + "\n\n"
			}

			d = strings.Trim(data.Consent, " \n")
			if d != "" {
				text += d + "\n\n"
			}

			d = strings.Trim(data.Transfers, " \n")
			if d != "" {
				text += d + "\n\n"
			}

			d = strings.Trim(data.TOM, " \n")
			if d != "" {
				text += d + "\n\n"
			}

			hasPrivacy = true
		}
	}

	return nil, text, hasPrivacy

}

func printPrivacy(config *Configuration) error {

	err, pageData := collectStructureFromFiles(config.Path)
	if err != nil {
		return err
	}

	err, data, _ := buildPrivacy(config, pageData)
	fmt.Println(data)
	return err
}
